Offshore Wind Balance of System Cost Modeling
=============================================

The balance-of-system (BOS) costs of an offshore wind plant include:

- Installation costs of the wind turbine (rotor-nacelle assembly and tower)
- Capital Expenditures (CapEx) and installation costs of the substructure
- CapEx and installation costs of the array and export cables
- CapEx and installation costs of the offshore substation (OSS)
- Onshore construction costs required to connect the turbine to the grid
- Port fees and commissioning costs

.. note::

    ORBIT does not specify a dollar-year when calculating BOS cost and it does
    not account for inflation. To provide a flexible and adaptable simulation
    model, components of the wind plant may incorporate `default` cost values.
    Please advise that these values are approximated using avaiable information
    or best-guess. To improve the fidelity of this tool, users should consider
    replacing the `default` values with better informed costs.

Evaluating BOS costs is complicated by the large number of design choices for
each component, the impact of weather delays on the installation processes, the
challenge of transporting and hoisting large components at sea, the variation
in geospatial characteristics between different projects, and the limited
number of vessels capable of conducting these operations.  The broad design
space associated with the BOS costs of an offshore wind project provides
significant opportunities for project developers to reduce overall costs
through innovative technologies and/or installation methodologies.

Some additional resources that describe offshore wind BOS in greater detail are
listed below

- `Guide to an Offshore Wind Farm (BVG Associates) <https://guidetoanoffshorewindfarm.com/>`_
